@@ -4,7 +4,6 @@ import collections
 
 import platform
 import re
-import xml.etree.ElementTree as ET
 
 from .constants import (
     xml_version, oval_header, timestamp, PREFIX_TO_NS, XCCDF11_NS, XCCDF12_NS)
@@ -37,12 +36,14 @@ def oval_generated_header(product_name, schema_version, ssg_version):
                        schema_version, timestamp)
 
 
-def register_namespaces():
+def register_namespaces(ns=None):
     """
     Register all possible namespaces
     """
     try:
-        for prefix, uri in PREFIX_TO_NS.items():
+        if ns is None:
+            ns = PREFIX_TO_NS
+        for prefix, uri in ns.items():
             ElementTree.register_namespace(prefix, uri)
     except Exception:
         # Probably an old version of Python
@@ -50,6 +51,24 @@ def register_namespaces():
         pass
 
 
+def get_namespaces_from(file):
+    """
+    Return dictionary of namespaces in file. Return empty dictionary in case of error.
+    """
+    result = {}
+    try:
+        result = {
+            key: value
+            for _, (key, value) in ElementTree.iterparse(file, events=["start-ns"])
+        }
+    except Exception:
+        # Probably an old version of Python
+        # Doesn't matter, as this is non-essential.
+        pass
+    finally:
+        return result
+
+
 def open_xml(filename):
     """
     Given a filename, register all possible namespaces, and return the XML tree.
@@ -444,5 +463,5 @@ class XMLCPEPlatform(XMLElement):
     def __init__(self, root):
         super(XMLCPEPlatform, self).__init__(root)
 
-    def find_all_fact_ref_elements(self):
-        return self.root.findall(".//cpe-lang:fact-ref", self.ns)
+    def find_all_check_fact_ref_elements(self):
+        return self.root.findall(".//cpe-lang:check-fact-ref", self.ns)
